package com.subd.subd.Controllers;

import com.subd.subd.Exceptions.IdNotFoundException;
import com.subd.subd.Models.Car;
import com.subd.subd.Repositories.CarRepository;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
public class CarController {
    private final CarRepository repository;
    CarController(CarRepository repository) {
        this.repository = repository;
    }
    // Aggregate root
    // tag::get-aggregate-root[]
    @GetMapping("/car")
    List<Car> all() {
        return repository.findAll();
    }
    // end::get-aggregate-root[]
    @PostMapping("/car")
    Car newCar(@RequestBody Car newCar) {
        return repository.save(newCar);
    }
    // Single item
    @GetMapping("/car/{id}")
    Car one(@PathVariable Long id) {
        return repository.findById(id)
                .orElseThrow(() -> new IdNotFoundException(id));
    }
    @PutMapping("/car/{id}")
    Car replaceCar(@RequestBody Car newCar, @PathVariable Long id) {
        return repository.findById(id)
                .map(car -> {
                    car.setGosNumber(newCar.getGosNumber());
                    car.setVin(newCar.getVin());
                    car.setDriver(newCar.getDriver());
                    return repository.save(car);
                })
                .orElseGet(() -> {
                    newCar.setId(id);
                    return repository.save(newCar);
                });
    }
    @DeleteMapping("/car/{id}")
    void deleteCar(@PathVariable Long id) {
        repository.deleteById(id);
    }
}
