package com.subd.subd.Controllers;

import com.subd.subd.Exceptions.IdNotFoundException;
import com.subd.subd.Models.Client;
import com.subd.subd.Repositories.ClientRepository;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
public class ClientController {
    private final ClientRepository repository;
    ClientController(ClientRepository repository) {
        this.repository = repository;
    }
    // Aggregate root
    // tag::get-aggregate-root[]
    @GetMapping("/client")
    List<Client> all() {
        return repository.findAll();
    }
    // end::get-aggregate-root[]
    @PostMapping("/client")
    Client newClient(@RequestBody Client newClient) {
        return repository.save(newClient);
    }
    // Single item
    @GetMapping("/client/{id}")
    Client one(@PathVariable Long id) {
        return repository.findById(id)
                .orElseThrow(() -> new IdNotFoundException(id));
    }
    @PutMapping("/client/{id}")
    Client replaceClient(@RequestBody Client newClient, @PathVariable Long id) {
        return repository.findById(id)
                .map(client -> {
                    client.setName(newClient.getName());
                    client.setPhone(newClient.getPhone());
                    client.setEmail(newClient.getEmail());
                    return repository.save(client);
                })
                .orElseGet(() -> {
                    newClient.setId(id);
                    return repository.save(newClient);
                });
    }
    @DeleteMapping("/client/{id}")
    void deleteClient(@PathVariable Long id) {
        repository.deleteById(id);
    }
}
