package com.subd.subd.Controllers;

import com.subd.subd.Exceptions.IdNotFoundException;
import com.subd.subd.Models.Driver;
import com.subd.subd.Repositories.DriverRepository;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
public class DriverController {
    private final DriverRepository repository;
    DriverController(DriverRepository repository) {
        this.repository = repository;
    }
    // Aggregate root
    // tag::get-aggregate-root[]
    @GetMapping("/driver")
    List<Driver> all() {
        return repository.findAll();
    }
    // end::get-aggregate-root[]
    @PostMapping("/driver")
    Driver newDriver(@RequestBody Driver newDriver) {
        return repository.save(newDriver);
    }
    // Single item
    @GetMapping("/driver/{id}")
    Driver one(@PathVariable Long id) {
        return repository.findById(id)
                .orElseThrow(() -> new IdNotFoundException(id));
    }
    @PutMapping("/driver/{id}")
    Driver replaceDriver(@RequestBody Driver newDriver, @PathVariable Long id) {
        return repository.findById(id)
                .map(driver -> {
                    driver.setName(newDriver.getName());
                    driver.setAge(newDriver.getAge());
                    driver.setPhone(newDriver.getPhone());
                    driver.setEmail(newDriver.getEmail());
                    return repository.save(driver);
                })
                .orElseGet(() -> {
                    newDriver.setId(id);
                    return repository.save(newDriver);
                });
    }
    @DeleteMapping("/driver/{id}")
    void deleteClient(@PathVariable Long id) {
        repository.deleteById(id);
    }
}
