package com.subd.subd.Controllers;

import com.subd.subd.Exceptions.IdNotFoundException;
import com.subd.subd.Models.Order;
import com.subd.subd.Repositories.OrderRepository;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
public class OrderController {
    private final OrderRepository repository;
    OrderController(OrderRepository repository) {
        this.repository = repository;
    }
    // Aggregate root
    // tag::get-aggregate-root[]
    @GetMapping("/order")
    List<Order> all() {
        return repository.findAll();
    }
    // end::get-aggregate-root[]
    @PostMapping("/order")
    Order newOrder(@RequestBody Order newOrder) {
        return repository.save(newOrder);
    }
    // Single item
    @GetMapping("/order/{id}")
    Order one(@PathVariable Long id) {
        return repository.findById(id)
                .orElseThrow(() -> new IdNotFoundException(id));
    }
    @PutMapping("/order/{id}")
    Order replaceOrder(@RequestBody Order newOrder, @PathVariable Long id) {
        return repository.findById(id)
                .map(order -> {
                    order.setValue(newOrder.getValue());
                    order.setClient(newOrder.getClient());
                    order.setSourcePickUpPoint(newOrder.getSourcePickUpPoint());
                    order.setDestPickUpPoint(newOrder.getDestPickUpPoint());
                    order.setCar(newOrder.getCar());
                    return repository.save(order);
                })
                .orElseGet(() -> {
                    newOrder.setId(id);
                    return repository.save(newOrder);
                });
    }
    @DeleteMapping("/order/{id}")
    void deleteOrder(@PathVariable Long id) {
        repository.deleteById(id);
    }
}
